Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BillingSummary ¶
type PlotModel ¶
type PlotModel struct {
Buckets []analytics.Bucket
Metric string // "cost" or "tokens"
TimeFrame time.Duration
Width int
Height int
}
type StackedPlotModel ¶
type StackedPlotModel struct {
DailySummaries []analytics.DailyBillingSummary
TimeFrame time.Duration
Width int
Height int
TopSKUs []string // Top SKUs to show in stacks
}
StackedPlotModel represents a plot with stacked bars by SKU
func NewStackedPlot ¶
func NewStackedPlot(summaries []analytics.DailyBillingSummary, timeFrame time.Duration, width, height int) StackedPlotModel
NewStackedPlot creates a new stacked plot from billing data
func (StackedPlotModel) View ¶
func (p StackedPlotModel) View() string
Source Files
¶
Click to show internal directories.
Click to hide internal directories.